# Localisation features

import slogan
__all__= slogan.autoPackage(__file__)

# Each Language class provides textual messages for that language, plus
# number formatting rules.

# Language - base class providing English messages and no special number formatting

class Language:
  identity= ''
  code= ''

  html_title_index= 'The Slogan Log Analyser'
  html_title_query= 'Slogan query'
  html_traits= 'Query on'
  html_currents= 'Current query'
  html_results= 'Results'
  html_display= 'Display'
  html_displays= {
    'list': 'list',
    'tree': 'tree',
    'bar': 'bar chart',
    'pie': 'pie chart'
  }
  html_sort= 'sorted'
  html_sorts= {
    'ascii': 'in natural order',
    'hits': 'by most hits',
    '-hits': 'by fewest hits'
  }
  html_change= 'Change'
  html_nomatch= 'No matches found'
  pie_other= 'Other'

  file_title= 'File requested'
  host_title= 'Host making request'
  type_title= 'Document type'
  browser_title= 'Browser'
  referrer_title= 'Referring page'
  cookie_title= 'Cookie returned'
  date_title= 'Date accessed'
  time_title= 'Time accessed'
  method_title= 'Request method'
  status_title= 'Response status'
  query_title= 'Query string'

  host_ip= 'Numerical IP addresses'
  cookie_none= 'No cookie'
  referrer_none= 'No referring page given'
  browser_unknown= 'Unknown'
  browser_none= 'No browser information given'
  type_none= 'No type logged'
  query_none= 'No query string'

  number_thousands= ''
  number_decimal= '.'

  date_months= {
    '00': '(month unreadable)',
    '01': 'January',
    '02': 'February',
    '03': 'March',
    '04': 'April',
    '05': 'May',
    '06': 'June',
    '07': 'July',
    '08': 'August',
    '09': 'September',
    '10': 'October',
    '11': 'November',
    '12': 'December'
  }
  status_names= {
    '0xx': '(status code unknown)',
    '1xx': 'Informational',
    '2xx': 'Successful',
    '3xx': 'Redirection',
    '4xx': 'Client Error',
    '5xx': 'Server Error',
    '100': 'Continue',
    '101': 'Switching Protocols',
    '200': 'OK',
    '201': 'Created',
    '202': 'Accepted',
    '203': 'Non-Authoritative Information',
    '204': 'No Content',
    '205': 'Reset Content',
    '206': 'Partial Content',
    '300': 'Multiple Choices',
    '301': 'Moved Permanently',
    '302': 'Found',
    '303': 'See Other',
    '304': 'Not Modified',
    '305': 'Use Proxy',
    '307': 'Temporary Redirect',
    '400': 'Bad Request',
    '401': 'Unauthorized',
    '402': 'Payment Required',
    '403': 'Forbidden',
    '404': 'Not Found',
    '405': 'Method Not Allowed',
    '407': 'Proxy Authentication Required',
    '408': 'Request Timeout',
    '409': 'Conflict',
    '410': 'Gone',
    '411': 'Length Required',
    '412': 'Precondition Failed',
    '413': 'Request Entity Too Large',
    '414': 'Request-URI Too Long',
    '415': 'Unsupported Media Type',
    '416': 'Requested Range Not Satisfiable',
    '417': 'Expectation Failed',
    '500': 'Internal Server Error',
    '501': 'Not Implemented',
    '502': 'Bad Gateway',
    '503': 'Service Unavailable',
    '504': 'Gateway Timeout',
    '505': 'HTTP Version Not Supported'
  }

# TLD names
# Not included: .arpa, .nato; .fx, .gb, .zr; .eu
# Included despite not being in ISO 3166-1: uk, je, gg, ac
# See: http://www.din.de/gremien/nas/nabd/iso3166ma/

  host_tlds= {
    'com': 'Commercial',
    'net': 'Networking',
    'org': 'Organisations',
    'edu': 'US educational institutions',
    'gov': 'US government',
    'mil': 'US military',
    'int': 'International organisations',
    'ac': 'Ascension Island',
    'ad': 'Andorra',
    'ae': 'United Arab Emirates',
    'af': 'Afghanistan',
    'ag': 'Antigua and Barbuda',
    'al': 'Albania',
    'am': 'Armenia',
    'an': 'Netherlands Antilles',
    'ao': 'Angola',
    'aq': 'Antartica',
    'ar': 'Argentina',
    'as': 'American Samoa',
    'at': 'Austria',
    'au': 'Australia',
    'aw': 'Aruba',
    'az': 'Azerbaijan',
    'ba': 'Bosnia and Herzegovina',
    'bb': 'Barbados',
    'bd': 'Bangladesh',
    'be': 'Belgium',
    'bf': 'Burkina Faso',
    'bg': 'Bulgaria',
    'bh': 'Bahrain',
    'bi': 'Burundi',
    'bj': 'Benin',
    'bm': 'Bermuda',
    'bn': 'Brunei',
    'bo': 'Bolivia',
    'br': 'Brazil',
    'bs': 'Bahamas',
    'bt': 'Bhutan',
    'bv': 'Bouvet Island',
    'bw': 'Botswana',
    'by': 'Belarus',
    'bz': 'Belize',
    'ca': 'Canada',
    'cc': 'Cocos (Keeling) Islands',
    'cd': 'Congo, Democratic People\'s Republic',
    'cf': 'Central African Republic',
    'cg': 'Congo, Republic of',
    'ch': 'Switzerland',
    'ci': 'Cte d\'Ivoire',
    'ck': 'Cook Islands',
    'cl': 'Chile',
    'cm': 'Cameroon',
    'cn': 'China',
    'co': 'Columbia',
    'cr': 'Costa Rica',
    'cu': 'Cuba',
    'cv': 'Cap Verde',
    'cx': 'Christmas Island',
    'cy': 'Cyprus',
    'cz': 'Czech Republic',
    'de': 'Germany',
    'dj': 'Djibouti',
    'dk': 'Denmark',
    'dm': 'Dominica',
    'do': 'Dominican Republic',
    'dz': 'Algeria',
    'ec': 'Ecuador',
    'ee': 'Estonia',
    'eg': 'Egypt',
    'eh': 'Western Sahara',
    'er': 'Eritrea',
    'es': 'Spain',
    'et': 'Ethiopia',
    'eu': 'European Union',
    'fi': 'Finland',
    'fj': 'Fiji',
    'fk': 'Falkland Islands',
    'fm': 'Micronesia, Federal State',
    'fo': 'Faroe Islands',
    'fr': 'France',
    'ga': 'Gabon',
    'gd': 'Grenada',
    'ge': 'Georgia',
    'gf': 'French Guiana',
    'gg': 'Guernsey',
    'gi': 'Gibralta',
    'gl': 'Greenland',
    'gm': 'Gambia',
    'gn': 'Guinea',
    'gp': 'Guadeloup',
    'gq': 'Equatorial Guinea',
    'gr': 'Greece',
    'gs': 'South Georgia and South Sandwich Islands',
    'gt': 'Guatemala',
    'gu': 'Guam',
    'gw': 'Guinea-Bissau',
    'gy': 'Guyana',
    'hk': 'Hong Kong',
    'hm': 'Heard and McDonald Islands',
    'hn': 'Honduras',
    'hr': 'Croatia',
    'ht': 'Haiti',
    'hu': 'Hungary',
    'id': 'Indonesia',
    'ie': 'Ireland',
    'il': 'Israel',
    'im': 'Isle of Man',
    'in': 'India',
    'io': 'British Indian Ocean Territory',
    'iq': 'Iraq',
    'ir': 'Iran',
    'is': 'Iceland',
    'it': 'Italy',
    'je': 'Jersey',
    'jm': 'Jamaica',
    'jo': 'Jordan',
    'jp': 'Japan',
    'ke': 'Kenya',
    'kg': 'Kyrgystan',
    'kh': 'Cambodia',
    'ki': 'Kiribati',
    'km': 'Comoros',
    'kn': 'Saint Kitts and Nevis',
    'kp': 'Korea, Democratic People\'s Republic',
    'kr': 'Korea, Republic of',
    'kw': 'Kuwait',
    'ky': 'Cayman Islands',
    'kz': 'Kazakstan',
    'la': 'Laos',
    'lb': 'Lebanon',
    'lc': 'Saint Lucia',
    'li': 'Liechtenstein',
    'lk': 'Sri Lanka',
    'lr': 'Liberia',
    'ls': 'Lesotho',
    'lt': 'Lithuania',
    'lu': 'Luxembourg',
    'lv': 'Latvia',
    'ly': 'Libya',
    'ma': 'Morocco',
    'mc': 'Monaco',
    'md': 'Moldova',
    'mg': 'Madagascar',
    'mh': 'Marshall Islands',
    'mk': 'Macedonia, Former Yugoslav Republic',
    'ml': 'Mali',
    'mm': 'Myanmar',
    'mn': 'Mongolia',
    'mo': 'Macau',
    'mp': 'Nothern Mariana Islands',
    'mq': 'Martinique',
    'mr': 'Mauritania',
    'ms': 'Montserrat',
    'mt': 'Malta',
    'mu': 'Mauritius',
    'mv': 'Maldives',
    'mw': 'Malawi',
    'mx': 'Mexico',
    'my': 'Malaysia',
    'mz': 'Mozambique',
    'na': 'Namibia',
    'nc': 'New Caledonia',
    'ne': 'Niger',
    'nf': 'Norfolk Island',
    'ng': 'Nigeria',
    'ni': 'Nicaragua',
    'nl': 'Netherlands',
    'no': 'Norway',
    'np': 'Nepal',
    'nr': 'Nauru',
    'nu': 'Niue',
    'nz': 'New Zealand',
    'om': 'Oman',
    'pa': 'Panama',
    'pe': 'Peru',
    'pf': 'French Polynesia',
    'pg': 'Papua New Guinea',
    'ph': 'Philippines',
    'pk': 'Pakistan',
    'pl': 'Poland',
    'pm': 'St. Pierre and Miquelon',
    'pn': 'Pitcairn Island',
    'pr': 'Puerto Rico',
    'ps': 'Palestine',
    'pt': 'Portugal',
    'pw': 'Palau',
    'py': 'Paraguay',
    'qa': 'Qatar',
    're': 'Reunion Island',
    'ru': 'Russian',
    'rw': 'Rwanda',
    'sa': 'Saudi Arabia',
    'sb': 'Solomon Islands',
    'sc': 'Seychelles',
    'sd': 'Sudan',
    'se': 'Sweden',
    'sg': 'Singapore',
    'sh': 'St. Helena',
    'si': 'Slovenia',
    'sj': 'Svalbard and Jan Mayen Islands',
    'sk': 'Slovakia',
    'sl': 'Sierra Leone',
    'sm': 'San Marino',
    'sn': 'Senegal',
    'so': 'Somalia',
    'sr': 'Suriname',
    'st': 'Sao Tome and Principe',
    'sv': 'El Salvador',
    'sy': 'Syria',
    'sz': 'Swaziland',
    'tc': 'Turks and Ciacos Islands',
    'td': 'Chad',
    'tf': 'French Southern Territories',
    'tg': 'Togo',
    'th': 'Thailand',
    'tj': 'Tajikistan',
    'tk': 'Tokelau',
    'tm': 'Turkmenistan',
    'tn': 'Tunisia',
    'to': 'Tonga',
    'tp': 'East Timor',
    'tr': 'Turkey',
    'tt': 'Trinidad and Tobago',
    'tv': 'Tuvalu',
    'tw': 'Taiwan',
    'tz': 'Tanzania',
    'ua': 'Ukraine',
    'ug': 'Uganda',
    'uk': 'United Kingdom',
    'um': 'US Minor Outlying Islands',
    'us': 'United States',
    'uy': 'Uruguay',
    'uz': 'Uzbeckistan',
    'va': 'Vatican',
    'vc': 'Saint Vincent and the Grenadines',
    've': 'Venezuela',
    'vg': 'Virgin Islands (British)',
    'vi': 'Virgin Islands (US)',
    'vn': 'Vietnam',
    'vu': 'Vanuatu',
    'wf': 'Wallis and Futuna Islands',
    'ws': 'Western Samoa',
    'ye': 'Yemen',
    'yt': 'Mayotte',
    'yu': 'Yugoslavia',
    'za': 'South Africa',
    'zm': 'Zambia',
    'zw': 'Zimbabwe'
  }

# EuropeanLanguage - base class for languages in continental Europe,
# where people write numebrs with ',' and '.' the other way around. Oh
# those wacky European japesters, eh, readers?

class EuropeanLanguage(Language):
  number_thousands= '.'
  number_decimal= ','
