"""
The Slogan Log Analyser
Pie-chart plotting code
"""

import slogan, slogan.html
[false, true]= range(2)
import os, os.path, math, string, cStringIO

try:
  import Image, ImageDraw, ImageFont
  available= true
except ImportError:
  available= false

def initialise(set):
  global config
  import slogan.settings
  config= slogan.settings.settings[set][2]

# getSlices -- get a list of pie slices (value, fraction) from a set of results. value is None for 'other'

def getSlices(results):
  total= reduce(lambda a, b: a+b, map(lambda x: x[1], results))
  others= []
  slices= []
  for (v, h) in results:
    if h<total*config['minSlice']:
      others.append(v, float(h)/total)
    else:
      slices.append(v, float(h)/total)

  while len(slices)+(len(others)>0) > config['maxSlices']:
    lowest= []
    lowhits= None
    for i in range(len(slices)):
      if lowhits==None or slices[i][1]<lowhits:
        lowest= [i]
        lowhits= slices[i][1]
      elif slices[i][1]==lowhits:
        lowest[:0]= [i]
    for i in lowest:
      others.append(slices[i])
      slices[i:i+1]= []

  if len(others)==1:
    slices.append(others[0])
  elif len(others)>1:
    slices.append((None, reduce(lambda a, b: a+b, map(lambda x: x[1], others))))
  return slices

# placeLabels -- work out where to put pie chart labels from a list of slices

def bboxUnion(a, b):
  return [min(a[0], b[0]), min(a[1], b[1]), max(a[2], b[2]), max(a[3], b[3])]

[up, middle, down]= range(3)

def placeLabels(context, slices):
  labelRadius= config['diameter']/2+config['labelGap']
  bbox= map(int, [-labelRadius, -labelRadius, labelRadius, labelRadius])
  font= ImageFont.load(config['font'])
  labels= []
  pos= 0.0

  q= context[0][-1]
  trait= slogan.traitObjects[q[0]]
  for (val, deg) in slices:
    labelAngle= pos+deg/2
    pos= pos+deg
    labelDirection= [1, -1][labelAngle>0.5]
    radAngle= 2*math.pi*(labelAngle-0.25)
    x= round(labelRadius*math.cos(radAngle))
    y= round(labelRadius*math.sin(radAngle))

    if val==None:
      text= slogan.language.pie_other
      icon= trait.icon(q[1])
    else:
      qv= q[1][:]
      if val!='':
        qv.append(val)
      text= trait.write(qv)
      icon= trait.icon(qv)
    percent= str(round(deg*1000)/10)

    if len(text)>config['labelLength']:
      text= '...'+text[-(config['labelLength']-3):]
    if labelDirection<0:
      text= percent+'% '+text
    else:
      text= text+' '+percent+'%'

    iconBbox= map(int, [x-10, y-10, x+10, y+10])
    textSize= font.getsize(text)
    labelPos= [ middle, [up, down][abs(labelAngle-0.5)>0.25] ][abs(labelAngle % 0.5 - 0.25)>0.22]
    textX= [ [x+10+4, x-10][labelPos!=middle], [x-10-4-textSize[0], x+10-textSize[0]][labelPos!=middle] ][labelDirection<0]
    textY= [y+10+4, y-textSize[1]/2, y-10-4-textSize[1]][labelPos]
    textBbox= map(int, [textX, textY, textX+textSize[0], textY+textSize[1]])

    bbox= reduce(bboxUnion, [bbox, iconBbox, textBbox])
    labels.append((val, text, icon, iconBbox, textBbox))
  return (font, bbox, labels)

# outputImage -- create image of pie chart using PIL.

def outputImage(stream, context, slices, format):
  (font, bbox, labels)= placeLabels(context, slices)
  size= config['diameter']*config['superscale']
  pie= Image.new('RGB', (size, size), config['palette'][0])
  draw= ImageDraw.Draw(pie)
  pos= 0.0

  for i in range(len(slices)):
    (val, deg)= slices[i]
    draw.pieslice((0, 0, size-1, size-1), round(pos*360-90), round((pos+deg)*360-90), fill= config['palette'][i+2])
    pos= pos+deg
  if config['superscale']!=1:
    pie= pie.resize((config['diameter'], config['diameter']), Image.BILINEAR)

  pic= Image.new('RGB', (bbox[2]-bbox[0], bbox[3]-bbox[1]), config['palette'][0])
  draw= ImageDraw.Draw(pic)
  pic.paste(pie, (-bbox[0]-config['diameter']/2, -bbox[1]-config['diameter']/2))

  for (val, text, icon, iconBbox, textBbox) in labels:
    draw.text((textBbox[0]-bbox[0], textBbox[1]-bbox[1]), text, font= font, fill= config['palette'][1])
    im= Image.open(slogan.html.findIcon(icon)[1])
    pic.paste(im, (iconBbox[0]-bbox[0], iconBbox[1]-bbox[1]))

  file= cStringIO.StringIO()
  pic.save(file, format)
  stream.write(file.getvalue())
  file.close()
