# Trait classes

import slogan
import string
__all__= slogan.autoPackage(__file__)

# Each property of a hit which is usable in the interface has a Trait subclass
# associated with it, which provides general information on the trait, and has
# functions to parse a logpart into a list of subparts and to process a list of
# subparts into a human-readable string.

# Trait objects themselves have no state, as trait data is in the database.
# Traits are only implemented as classes so we can use inheritance.

# Trait interface:
#   identity
#     string identifier for trait, used in log format strings and stuff
#  extended
#     identifier for trait as used in the W3C Extended logfile format
#     (case-insensitive)
#  priority
#     integer priority; the higher, the nearer it will be to the top of the
#     list of traits in the interface. -ve values are not shown.
#   title
#     textual description of trait, to be used in interface
#   size
#     list of maximum string lengths for each subpart of the trait
#   read(logpart)
#     convert a string extracted for the trait from a log line into a subpart
#     list
#   write(partlist)
#     take a subpart list and give a readable string representing it in the
#     user interface
#   icon(partlist)
#     for a subpart list, return a icon id list

# An icon id list is a list of filename parts to look up. For example, for an
# icon id list of ['type', 'text', 'html'], Slogan will look for icon files in
# this order:
#   icon/type/text/html.gif
#   icon/type/text.gif
#   icon/type.gif
#   icon.gif
# The first of these files that exists will be shown in the interface.

# Trait - all traits are derived from this virtual class, which gives
# default functions for a shallow (ie. non-hierarchical) property.

class Trait:
  identity= ''
  extended= ''
  priority= 10
  title= '(trait)'
  size= []
  def read(self, logpart):
    return [logpart]
  def write(self, partlist):
    return string.join(partlist, ' ')
  def icon(self, partlist):
    return [self.identity]+partlist
